Package: symTensor
Type: Package
Title: Symmetric Matrix and Tensor Decomposition
Version: 0.1.0
Authors@R: person("Koki", "Tsuyuzaki", email = "k.t.the-answer@hotmail.co.jp",
    role = c("aut", "cre"))
Description: Provides symmetric matrix and tensor operations and decomposition
    algorithms including symmetric NMF (symNMF), PageRank, Label Propagation,
    Higher-order Power Method, and TOPHITS. Designed to work with 'rTensor'
    objects. Methods are described in Kuang et al. (2012)
    <doi:10.1137/1.9781611972825.10>, Kolda and Mayo (2011)
    <doi:10.1137/100801482>, and Kolda and Bader (2006)
    <doi:10.1137/1.9781611972764.26>.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 3.5.0)
Imports: rTensor, methods, stats
Suggests: testthat
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-05-11 07:12:29 UTC; koki
Author: Koki Tsuyuzaki [aut, cre]
Maintainer: Koki Tsuyuzaki <k.t.the-answer@hotmail.co.jp>
Repository: CRAN
Date/Publication: 2026-05-14 09:50:02 UTC
Built: R 4.6.0; ; 2026-05-14 09:59:52 UTC; unix
