# Generated by roxygen2: do not edit by hand

export(HigherOrderPower)
export(LabelPropagation)
export(PageRank)
export(Symmetrize)
export(TOPHITS)
export(isSymmetricTensor)
export(symNMF)
import(methods)
import(rTensor)
importFrom(stats,rnorm)
importFrom(stats,runif)
